{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "kant.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
The actual image registry, generates offline or online image registry 
according to environmental conditions.
*/}}
{{- define "kant.imageRegistry" -}}
{{- if .Values.global.offlineRegistry }}
{{- .Values.global.offlineRegistry}}/{{ .Values.global.imageRegistry }}
{{- else }}
{{- .Values.global.imageRegistry }}
{{- end }}
{{- end }}

{{/* Common labels. */}}
{{- define "kant.labels" -}}
helm.sh/chart: {{ include "kant.chart" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Create the name of the service account to use.
*/}}
{{- define "kant.serviceAccountName" -}}
{{- if .Values.global.kant.rbac }}
{{- default "kant-admin" .Values.global.kant.serviceAccountName }}
{{- else }}
{{- default "default" .Values.global.kant.serviceAccountName }}
{{- end }}
{{- end }}

{{/* Image url of crds operator job */}}
{{- define "kant.crdsOperatorImage" -}}
{{- with .Values.hooks.crdsOperator }}
{{- if $.Values.global.offlineRegistry }}
{{- $.Values.global.offlineRegistry }}/{{ .registry }}/{{ .repository }}:{{ .tag }}
{{- else }}
{{- .registry }}/{{ .repository }}:{{ .tag }}
{{- end }}
{{- end }}
{{- end }}